r19733 - gnucash/trunk/src - Preferences window improvements:

Geert Janssens gjanssens at code.gnucash.org
Sat Oct 30 10:55:23 EDT 2010


Author: gjanssens
Date: 2010-10-30 10:55:23 -0400 (Sat, 30 Oct 2010)
New Revision: 19733
Trac: http://svn.gnucash.org/trac/changeset/19733

Modified:
   gnucash/trunk/src/business/business-gnome/dialog-invoice.c
   gnucash/trunk/src/business/business-gnome/dialog-order.c
   gnucash/trunk/src/business/business-gnome/glade/businessprefs.glade
   gnucash/trunk/src/business/business-gnome/schemas/apps_gnucash_dialog_business_common.schemas.in
   gnucash/trunk/src/core-utils/gnc-gconf-utils.h
   gnucash/trunk/src/gnome-utils/glade/preferences.glade
   gnucash/trunk/src/gnome-utils/gnc-gnome-utils.c
   gnucash/trunk/src/gnome/dialog-sx-editor.c
   gnucash/trunk/src/gnome/gnc-plugin-page-register.c
   gnucash/trunk/src/gnome/gnc-plugin-page-register.h
   gnucash/trunk/src/gnome/gnc-split-reg.c
   gnucash/trunk/src/gnome/schemas/apps_gnucash_general.schemas.in
   gnucash/trunk/src/register/register-gnome/gnucash-sheet.c
   gnucash/trunk/src/register/register-gnome/gnucash-sheet.h
Log:
Preferences window improvements:
* Accounting Period: reorder options so the dates are on top
* Business: reorder options to clarify which options are general and which apply to invoices or bills only
* Business: remove obscure "Number of lines" option
* Register defaults: remove obscure "Number of lines" option
* General: remove "Show splash screen" option

While removing the "Number of lines" options, I have also removed most of the code that used this option. The number of lines was used to calculate the default window size in various places in the code. The code now simply uses sensible defaults for that.

Modified: gnucash/trunk/src/business/business-gnome/dialog-invoice.c
===================================================================
--- gnucash/trunk/src/business/business-gnome/dialog-invoice.c	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/business/business-gnome/dialog-invoice.c	2010-10-30 14:55:23 UTC (rev 19733)
@@ -2116,14 +2116,7 @@
     /* Create the register */
     {
         GtkWidget *regWidget, *frame, *window;
-        guint num_rows;
 
-        num_rows = gnc_gconf_get_float(GCONF_SECTION_INVOICE,
-                                       KEY_NUMBER_OF_ROWS, NULL);
-        if (num_rows == 0)
-            num_rows = 10;
-        gnucash_register_set_initial_rows( num_rows );
-
         /* Watch the order of operations, here... */
         regWidget = gnucash_register_new (gnc_entry_ledger_get_table
                                           (entry_ledger));

Modified: gnucash/trunk/src/business/business-gnome/dialog-order.c
===================================================================
--- gnucash/trunk/src/business/business-gnome/dialog-order.c	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/business/business-gnome/dialog-order.c	2010-10-30 14:55:23 UTC (rev 19733)
@@ -631,7 +631,6 @@
     //  gnc_entry_ledger_load (entry_ledger, entries);
 
     /* Watch the order of operations, here... */
-    gnucash_register_set_initial_rows( 10 );
     regWidget = gnucash_register_new (gnc_entry_ledger_get_table (entry_ledger));
     gnc_table_init_gui( regWidget, entry_ledger );
     ow->reg = GNUCASH_REGISTER (regWidget);

Modified: gnucash/trunk/src/business/business-gnome/glade/businessprefs.glade
===================================================================
--- gnucash/trunk/src/business/business-gnome/glade/businessprefs.glade	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/business/business-gnome/glade/businessprefs.glade	2010-10-30 14:55:23 UTC (rev 19733)
@@ -33,6 +33,8 @@
           </widget>
           <packing>
             <property name="right_attach">2</property>
+            <property name="top_attach">3</property>
+            <property name="bottom_attach">4</property>
             <property name="x_options">GTK_FILL</property>
             <property name="y_options"></property>
           </packing>
@@ -148,8 +150,8 @@
           </widget>
           <packing>
             <property name="right_attach">2</property>
-            <property name="top_attach">3</property>
-            <property name="bottom_attach">4</property>
+            <property name="top_attach">4</property>
+            <property name="bottom_attach">5</property>
             <property name="x_options">GTK_FILL</property>
             <property name="y_options"></property>
             <property name="x_padding">12</property>
@@ -175,40 +177,6 @@
           </packing>
         </child>
         <child>
-          <widget class="GtkLabel" id="label14">
-            <property name="visible">True</property>
-            <property name="xalign">0</property>
-            <property name="label" translatable="yes">Number of _rows:</property>
-            <property name="use_underline">True</property>
-            <property name="mnemonic_widget">gconf/dialogs/business/invoice/number_of_rows</property>
-          </widget>
-          <packing>
-            <property name="left_attach">2</property>
-            <property name="right_attach">3</property>
-            <property name="top_attach">2</property>
-            <property name="bottom_attach">3</property>
-            <property name="x_options">GTK_FILL</property>
-            <property name="y_options"></property>
-          </packing>
-        </child>
-        <child>
-          <widget class="GtkSpinButton" id="gconf/dialogs/business/invoice/number_of_rows">
-            <property name="visible">True</property>
-            <property name="can_focus">True</property>
-            <property name="tooltip" translatable="yes">Default number of register rows to display in Invoices.</property>
-            <property name="adjustment">1 0 100 1 10 0</property>
-            <property name="climb_rate">1</property>
-          </widget>
-          <packing>
-            <property name="left_attach">3</property>
-            <property name="right_attach">4</property>
-            <property name="top_attach">2</property>
-            <property name="bottom_attach">3</property>
-            <property name="x_options"></property>
-            <property name="y_options"></property>
-          </packing>
-        </child>
-        <child>
           <widget class="GtkCheckButton" id="gconf/dialogs/business/invoice/use_new_window">
             <property name="label" translatable="yes">_Open in new window</property>
             <property name="visible">True</property>
@@ -269,6 +237,25 @@
         <child>
           <placeholder/>
         </child>
+        <child>
+          <placeholder/>
+        </child>
+        <child>
+          <placeholder/>
+        </child>
+        <child>
+          <widget class="GtkLabel" id="label1">
+            <property name="visible">True</property>
+            <property name="xalign">0</property>
+            <property name="yalign">0.47999998927116394</property>
+            <property name="label" translatable="yes">&lt;b&gt;General&lt;/b&gt;</property>
+            <property name="use_markup">True</property>
+          </widget>
+          <packing>
+            <property name="x_options">GTK_FILL</property>
+            <property name="y_options"></property>
+          </packing>
+        </child>
       </widget>
     </child>
   </widget>

Modified: gnucash/trunk/src/business/business-gnome/schemas/apps_gnucash_dialog_business_common.schemas.in
===================================================================
--- gnucash/trunk/src/business/business-gnome/schemas/apps_gnucash_dialog_business_common.schemas.in	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/business/business-gnome/schemas/apps_gnucash_dialog_business_common.schemas.in	2010-10-30 14:55:23 UTC (rev 19733)
@@ -98,23 +98,6 @@
     </schema>
 
     <schema>
-      <key>/schemas/apps/gnucash/dialogs/business/invoice/number_of_rows</key>
-      <applyto>/apps/gnucash/dialogs/business/invoice/number_of_rows</applyto>
-      <owner>gnucash</owner>
-      <type>float</type>
-      <default>10.0</default>
-      <locale name="C">
-        <short>The number of rows in an invoice</short>
-        <long>
-	  This field sets the number of rows to show in an invoice.
-	  It does not actually affect the display of the contents of
-	  the window.  It is only used to set the size of the window
-	  when first opened.
-	</long>
-      </locale>
-    </schema>
-
-    <schema>
       <key>/schemas/apps/gnucash/dialogs/business/bill/notify_when_due</key>
       <applyto>/apps/gnucash/dialogs/business/bill/notify_when_due</applyto>
       <owner>gnucash</owner>

Modified: gnucash/trunk/src/core-utils/gnc-gconf-utils.h
===================================================================
--- gnucash/trunk/src/core-utils/gnc-gconf-utils.h	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/core-utils/gnc-gconf-utils.h	2010-10-30 14:55:23 UTC (rev 19733)
@@ -64,7 +64,6 @@
 #define KEY_ACCOUNTING_LABELS	"use_accounting_labels"
 #define KEY_ACCOUNT_SEPARATOR	"account_separator"
 #define KEY_NEGATIVE_IN_RED	"negative_in_red"
-#define KEY_NUMBER_OF_ROWS	"number_of_rows"
 #define KEY_ENABLE_EURO		"enable_euro"
 #define KEY_DATE_FORMAT 	"date_format"
 #define KEY_SHOW_LEAF_ACCOUNT_NAMES "show_leaf_account_names"

Modified: gnucash/trunk/src/gnome/dialog-sx-editor.c
===================================================================
--- gnucash/trunk/src/gnome/dialog-sx-editor.c	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/gnome/dialog-sx-editor.c	2010-10-30 14:55:23 UTC (rev 19733)
@@ -1366,7 +1366,6 @@
     gnc_plugin_page_set_ui_description (sxed->plugin_page,
                                         "gnc-sxed-window-ui-full.xml");
     gnc_plugin_page_register_set_options (sxed->plugin_page,
-                                          NULL, NULL,
                                           NUM_LEDGER_LINES_DEFAULT, FALSE );
     gnc_embedded_window_open_page (sxed->embed_window, sxed->plugin_page);
 

Modified: gnucash/trunk/src/gnome/gnc-plugin-page-register.c
===================================================================
--- gnucash/trunk/src/gnome/gnc-plugin-page-register.c	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/gnome/gnc-plugin-page-register.c	2010-10-30 14:55:23 UTC (rev 19733)
@@ -78,9 +78,7 @@
 /* This static indicates the debugging module that this .o belongs to.  */
 static QofLogModule log_module = GNC_MOD_GUI;
 
-#define DEFAULT_LINES_OPTION_SECTION GCONF_GENERAL_REGISTER
-#define DEFAULT_LINES_OPTION_NAME    KEY_NUMBER_OF_ROWS
-#define DEFAULT_LINES_AMOUNT         20
+#define DEFAULT_LINES_AMOUNT         50
 
 static void gnc_plugin_page_register_class_init (GncPluginPageRegisterClass *klass);
 static void gnc_plugin_page_register_init (GncPluginPageRegister *plugin_page);
@@ -464,8 +462,6 @@
     gint component_manager_id;
     GncGUID key;  /* The guid of the Account we're watching */
 
-    const char *lines_opt_section;
-    const char *lines_opt_name;
     gint lines_default;
     gboolean read_only;
 
@@ -683,8 +679,6 @@
     gnc_plugin_init_short_names (action_group, toolbar_labels);
     gnc_plugin_set_important_actions (action_group, important_actions);
 
-    priv->lines_opt_section = DEFAULT_LINES_OPTION_SECTION;
-    priv->lines_opt_name    = DEFAULT_LINES_OPTION_NAME;
     priv->lines_default     = DEFAULT_LINES_AMOUNT;
     priv->read_only         = FALSE;
     priv->fd.cleared_match  = CLEARED_ALL;
@@ -832,17 +826,9 @@
     priv->widget = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (priv->widget);
 
-    if (priv->lines_opt_section)
-    {
-        numRows = gnc_gconf_get_float (priv->lines_opt_section,
-                                       priv->lines_opt_name, NULL);
-    }
-    else
-    {
-        numRows = priv->lines_default;
-    }
+    numRows = priv->lines_default;
+    numRows = MIN(numRows, DEFAULT_LINES_AMOUNT);
 
-    numRows = MIN(numRows, 50);
     gnc_window = GNC_WINDOW(GNC_PLUGIN_PAGE(page)->window);
     gsr = gnc_split_reg_new(priv->ledger,
                             gnc_window_get_gtk_window(gnc_window),
@@ -3132,8 +3118,6 @@
 
 void
 gnc_plugin_page_register_set_options (GncPluginPage *plugin_page,
-                                      const char *lines_opt_section,
-                                      const char *lines_opt_name,
                                       gint lines_default,
                                       gboolean read_only)
 {
@@ -3144,9 +3128,7 @@
 
     page = GNC_PLUGIN_PAGE_REGISTER (plugin_page);
     priv = GNC_PLUGIN_PAGE_REGISTER_GET_PRIVATE(page);
-    priv->lines_opt_section = lines_opt_section;
-    priv->lines_opt_name 	= lines_opt_name;
-    priv->lines_default  	= lines_default;
+    priv->lines_default     = lines_default;
     priv->read_only         = read_only;
 }
 

Modified: gnucash/trunk/src/gnome/gnc-plugin-page-register.h
===================================================================
--- gnucash/trunk/src/gnome/gnc-plugin-page-register.h	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/gnome/gnc-plugin-page-register.h	2010-10-30 14:55:23 UTC (rev 19733)
@@ -114,21 +114,13 @@
  *
  *  @param plugin_page The "register" page to modify.
  *
- *  @param lines_opt_page The name of the options page containing the
- *  number of lines per register.
+ *  @param lines_default Used to calculate the minimum preferred height of
+ *                       the plugin page.
  *
- *  @param lines_opt_name The name of the options (within the page
- *  specified above) containing the number of lines per register.
- *
- *  @param lines_default The number of lines to use if the specified
- *  options cannot be found or has never been set.
- *
  *  @param read_only True if the register should be read-only.
  */
 void
 gnc_plugin_page_register_set_options (GncPluginPage *plugin_page,
-                                      const char *lines_opt_page,
-                                      const char *lines_opt_name,
                                       gint lines_default,
                                       gboolean read_only);
 

Modified: gnucash/trunk/src/gnome/gnc-split-reg.c
===================================================================
--- gnucash/trunk/src/gnome/gnc-split-reg.c	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/gnome/gnc-split-reg.c	2010-10-30 14:55:23 UTC (rev 19733)
@@ -344,8 +344,7 @@
     gsr->sort_type = BY_STANDARD;
     gsr->width = -1;
     gsr->height = -1;
-    gsr->numRows = gnc_gconf_get_float(GCONF_GENERAL_REGISTER,
-                                       KEY_NUMBER_OF_ROWS, NULL);
+    gsr->numRows = 10;
     gsr->read_only = FALSE;
 
     g_signal_connect( gsr, "destroy",
@@ -398,7 +397,6 @@
 
     /* FIXME: We'd really rather pass this down... */
     sr = gnc_ledger_display_get_split_register( gsr->ledger );
-    gnucash_register_set_initial_rows( gsr->numRows );
     register_widget = gnucash_register_new( sr->table );
     gsr->reg = GNUCASH_REGISTER( register_widget );
     gnc_table_init_gui( GTK_WIDGET(gsr->reg), sr );

Modified: gnucash/trunk/src/gnome/schemas/apps_gnucash_general.schemas.in
===================================================================
--- gnucash/trunk/src/gnome/schemas/apps_gnucash_general.schemas.in	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/gnome/schemas/apps_gnucash_general.schemas.in	2010-10-30 14:55:23 UTC (rev 19733)
@@ -302,21 +302,6 @@
     </schema>
 
     <schema>
-      <key>/schemas/apps/gnucash/general/show_splash_screen</key>
-      <applyto>/apps/gnucash/general/show_splash_screen</applyto>
-      <owner>gnucash</owner>
-      <type>bool</type>
-      <default>TRUE</default>
-      <locale name="C">
-        <short>Show splash screen</short>
-        <long>
-	  If active, a splash screen will be shown at
-	  startup. Otherwise no splash screen will be shown.
-	</long>
-      </locale>
-    </schema>
-
-    <schema>
       <key>/schemas/apps/gnucash/general/register/use_theme_colors</key>
       <applyto>/apps/gnucash/general/register/use_theme_colors</applyto>
       <owner>gnucash</owner>
@@ -493,23 +478,6 @@
     </schema>
 
     <schema>
-      <key>/schemas/apps/gnucash/general/register/number_of_rows</key>
-      <applyto>/apps/gnucash/general/register/number_of_rows</applyto>
-      <owner>gnucash</owner>
-      <type>float</type>
-      <default>10.0</default>
-      <locale name="C">
-        <short>The number of rows in an invoice</short>
-        <long>
-	  This field sets the number of rows to show in a register.
-	  It does not actually affect the display of the contents of
-	  the window.  It is only used to set the size of the window
-	  when first opened.
-	</long>
-      </locale>
-    </schema>
-
-    <schema>
       <key>/schemas/apps/gnucash/general/report/use_new_window</key>
       <applyto>/apps/gnucash/general/report/use_new_window</applyto>
       <owner>gnucash</owner>

Modified: gnucash/trunk/src/gnome-utils/glade/preferences.glade
===================================================================
--- gnucash/trunk/src/gnome-utils/glade/preferences.glade	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/gnome-utils/glade/preferences.glade	2010-10-30 14:55:23 UTC (rev 19733)
@@ -149,6 +149,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
+                    <property name="top_attach">8</property>
+                    <property name="bottom_attach">9</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                   </packing>
@@ -165,8 +167,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">1</property>
-                    <property name="bottom_attach">2</property>
+                    <property name="top_attach">9</property>
+                    <property name="bottom_attach">10</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -184,8 +186,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">2</property>
-                    <property name="bottom_attach">3</property>
+                    <property name="top_attach">10</property>
+                    <property name="bottom_attach">11</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -200,8 +202,6 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">4</property>
-                    <property name="bottom_attach">5</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                   </packing>
@@ -215,8 +215,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">8</property>
-                    <property name="bottom_attach">9</property>
+                    <property name="top_attach">4</property>
+                    <property name="bottom_attach">5</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                   </packing>
@@ -232,8 +232,8 @@
                     <property name="draw_indicator">True</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">5</property>
-                    <property name="bottom_attach">6</property>
+                    <property name="top_attach">1</property>
+                    <property name="bottom_attach">2</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options">GTK_FILL</property>
                     <property name="x_padding">12</property>
@@ -251,8 +251,8 @@
                     <property name="group">gconf/window/pages/account_tree/summary/start_choice/relative</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">6</property>
-                    <property name="bottom_attach">7</property>
+                    <property name="top_attach">2</property>
+                    <property name="bottom_attach">3</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options">GTK_FILL</property>
                     <property name="x_padding">12</property>
@@ -269,8 +269,8 @@
                     <property name="draw_indicator">True</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">9</property>
-                    <property name="bottom_attach">10</property>
+                    <property name="top_attach">5</property>
+                    <property name="bottom_attach">6</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options">GTK_FILL</property>
                     <property name="x_padding">12</property>
@@ -288,8 +288,8 @@
                     <property name="group">gconf/window/pages/account_tree/summary/end_choice/relative</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">10</property>
-                    <property name="bottom_attach">11</property>
+                    <property name="top_attach">6</property>
+                    <property name="bottom_attach">7</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options">GTK_FILL</property>
                     <property name="x_padding">12</property>
@@ -303,8 +303,8 @@
                   <packing>
                     <property name="left_attach">1</property>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">6</property>
-                    <property name="bottom_attach">7</property>
+                    <property name="top_attach">2</property>
+                    <property name="bottom_attach">3</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options">GTK_FILL</property>
                   </packing>
@@ -317,8 +317,8 @@
                   <packing>
                     <property name="left_attach">1</property>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">10</property>
-                    <property name="bottom_attach">11</property>
+                    <property name="top_attach">6</property>
+                    <property name="bottom_attach">7</property>
                     <property name="y_options">GTK_FILL</property>
                   </packing>
                 </child>
@@ -331,8 +331,8 @@
                   <packing>
                     <property name="left_attach">1</property>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">9</property>
-                    <property name="bottom_attach">10</property>
+                    <property name="top_attach">5</property>
+                    <property name="bottom_attach">6</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options">GTK_FILL</property>
                   </packing>
@@ -347,8 +347,8 @@
                   <packing>
                     <property name="left_attach">1</property>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">5</property>
-                    <property name="bottom_attach">6</property>
+                    <property name="top_attach">1</property>
+                    <property name="bottom_attach">2</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options">GTK_FILL</property>
                   </packing>
@@ -1263,8 +1263,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">3</property>
-                    <property name="bottom_attach">4</property>
+                    <property name="top_attach">2</property>
+                    <property name="bottom_attach">3</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -1357,8 +1357,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">11</property>
-                    <property name="bottom_attach">12</property>
+                    <property name="top_attach">10</property>
+                    <property name="bottom_attach">11</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -1372,8 +1372,8 @@
                     <property name="use_markup">True</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">10</property>
-                    <property name="bottom_attach">11</property>
+                    <property name="top_attach">9</property>
+                    <property name="bottom_attach">10</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                   </packing>
@@ -1384,8 +1384,8 @@
                     <property name="xalign">0</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">9</property>
-                    <property name="bottom_attach">10</property>
+                    <property name="top_attach">8</property>
+                    <property name="bottom_attach">9</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                   </packing>
@@ -1399,8 +1399,8 @@
                     <property name="mnemonic_widget">gconf/general/auto_decimal_places</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">8</property>
-                    <property name="bottom_attach">9</property>
+                    <property name="top_attach">7</property>
+                    <property name="bottom_attach">8</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -1417,8 +1417,8 @@
                   <packing>
                     <property name="left_attach">1</property>
                     <property name="right_attach">2</property>
-                    <property name="top_attach">8</property>
-                    <property name="bottom_attach">9</property>
+                    <property name="top_attach">7</property>
+                    <property name="bottom_attach">8</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                   </packing>
@@ -1435,8 +1435,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">7</property>
-                    <property name="bottom_attach">8</property>
+                    <property name="top_attach">6</property>
+                    <property name="bottom_attach">7</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -1454,8 +1454,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">6</property>
-                    <property name="bottom_attach">7</property>
+                    <property name="top_attach">5</property>
+                    <property name="bottom_attach">6</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -1469,8 +1469,8 @@
                     <property name="use_markup">True</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">5</property>
-                    <property name="bottom_attach">6</property>
+                    <property name="top_attach">4</property>
+                    <property name="bottom_attach">5</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                   </packing>
@@ -1535,25 +1535,6 @@
                   </packing>
                 </child>
                 <child>
-                  <widget class="GtkCheckButton" id="gconf/general/show_splash_screen">
-                    <property name="label" translatable="yes">Show splash scree_n</property>
-                    <property name="visible">True</property>
-                    <property name="can_focus">True</property>
-                    <property name="receives_default">False</property>
-                    <property name="tooltip" translatable="yes">Show splash screen at startup.</property>
-                    <property name="use_underline">True</property>
-                    <property name="draw_indicator">True</property>
-                  </widget>
-                  <packing>
-                    <property name="right_attach">4</property>
-                    <property name="top_attach">2</property>
-                    <property name="bottom_attach">3</property>
-                    <property name="x_options">GTK_FILL</property>
-                    <property name="y_options"></property>
-                    <property name="x_padding">12</property>
-                  </packing>
-                </child>
-                <child>
                   <widget class="GtkLabel" id="label119">
                     <property name="visible">True</property>
                     <property name="xalign">0</property>
@@ -1562,8 +1543,8 @@
                     <property name="mnemonic_widget">gconf/general/autosave_interval_minutes</property>
                   </widget>
                   <packing>
-                    <property name="top_attach">13</property>
-                    <property name="bottom_attach">14</property>
+                    <property name="top_attach">12</property>
+                    <property name="bottom_attach">13</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -1602,8 +1583,8 @@
                   <packing>
                     <property name="left_attach">1</property>
                     <property name="right_attach">3</property>
-                    <property name="top_attach">13</property>
-                    <property name="bottom_attach">14</property>
+                    <property name="top_attach">12</property>
+                    <property name="bottom_attach">13</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options">GTK_FILL</property>
                   </packing>
@@ -1620,8 +1601,8 @@
                   </widget>
                   <packing>
                     <property name="right_attach">4</property>
-                    <property name="top_attach">12</property>
-                    <property name="bottom_attach">13</property>
+                    <property name="top_attach">11</property>
+                    <property name="bottom_attach">12</property>
                     <property name="x_options">GTK_FILL</property>
                     <property name="y_options"></property>
                     <property name="x_padding">12</property>
@@ -1684,6 +1665,18 @@
                   </packing>
                 </child>
                 <child>
+                  <widget class="GtkLabel" id="label9">
+                    <property name="visible">True</property>
+                    <property name="xalign">0</property>
+                  </widget>
+                  <packing>
+                    <property name="top_attach">3</property>
+                    <property name="bottom_attach">4</property>
+                    <property name="x_options">GTK_FILL</property>
+                    <property name="y_options"></property>
+                  </packing>
+                </child>
+                <child>
                   <placeholder/>
                 </child>
                 <child>
@@ -1782,6 +1775,27 @@
                 <child>
                   <placeholder/>
                 </child>
+                <child>
+                  <placeholder/>
+                </child>
+                <child>
+                  <placeholder/>
+                </child>
+                <child>
+                  <placeholder/>
+                </child>
+                <child>
+                  <widget class="GtkLabel" id="label10">
+                    <property name="visible">True</property>
+                    <property name="xalign">0</property>
+                  </widget>
+                  <packing>
+                    <property name="top_attach">13</property>
+                    <property name="bottom_attach">14</property>
+                    <property name="x_options">GTK_FILL</property>
+                    <property name="y_options"></property>
+                  </packing>
+                </child>
               </widget>
               <packing>
                 <property name="position">3</property>
@@ -2348,7 +2362,7 @@
               <widget class="GtkTable" id="table4">
                 <property name="visible">True</property>
                 <property name="border_width">6</property>
-                <property name="n_rows">11</property>
+                <property name="n_rows">10</property>
                 <property name="n_columns">4</property>
                 <child>
                   <widget class="GtkLabel" id="label63">
@@ -2448,22 +2462,6 @@
                   </packing>
                 </child>
                 <child>
-                  <widget class="GtkLabel" id="label43">
-                    <property name="visible">True</property>
-                    <property name="xalign">0</property>
-                    <property name="label" translatable="yes">Number of _rows:</property>
-                    <property name="use_underline">True</property>
-                    <property name="mnemonic_widget">gconf/general/register/number_of_rows</property>
-                  </widget>
-                  <packing>
-                    <property name="top_attach">10</property>
-                    <property name="bottom_attach">11</property>
-                    <property name="x_options">GTK_FILL</property>
-                    <property name="y_options"></property>
-                    <property name="x_padding">12</property>
-                  </packing>
-                </child>
-                <child>
                   <widget class="GtkLabel" id="label59">
                     <property name="visible">True</property>
                     <property name="xalign">0</property>
@@ -2557,26 +2555,6 @@
                   </packing>
                 </child>
                 <child>
-                  <widget class="GtkSpinButton" id="gconf/general/register/number_of_rows">
-                    <property name="visible">True</property>
-                    <property name="can_focus">True</property>
-                    <property name="tooltip" translatable="yes">Display this many rows when a register is created.</property>
-                    <property name="adjustment">20 1 200 1 10 0</property>
-                    <property name="climb_rate">1</property>
-                    <property name="snap_to_ticks">True</property>
-                    <property name="numeric">True</property>
-                    <property name="update_policy">if-valid</property>
-                  </widget>
-                  <packing>
-                    <property name="left_attach">1</property>
-                    <property name="right_attach">2</property>
-                    <property name="top_attach">10</property>
-                    <property name="bottom_attach">11</property>
-                    <property name="x_options">GTK_FILL</property>
-                    <property name="y_options"></property>
-                  </packing>
-                </child>
-                <child>
                   <placeholder/>
                 </child>
                 <child>
@@ -2609,12 +2587,6 @@
                 <child>
                   <placeholder/>
                 </child>
-                <child>
-                  <placeholder/>
-                </child>
-                <child>
-                  <placeholder/>
-                </child>
               </widget>
               <packing>
                 <property name="position">6</property>

Modified: gnucash/trunk/src/gnome-utils/gnc-gnome-utils.c
===================================================================
--- gnucash/trunk/src/gnome-utils/gnc-gnome-utils.c	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/gnome-utils/gnc-gnome-utils.c	2010-10-30 14:55:23 UTC (rev 19733)
@@ -596,8 +596,7 @@
 
     g_set_application_name(PACKAGE_NAME);
 
-    if (gnc_gconf_get_bool(GCONF_GENERAL, "show_splash_screen", NULL))
-        gnc_gui_init_splash();
+    gnc_gui_init_splash();
 
     gnome_is_initialized = TRUE;
 

Modified: gnucash/trunk/src/register/register-gnome/gnucash-sheet.c
===================================================================
--- gnucash/trunk/src/register/register-gnome/gnucash-sheet.h	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/register/register-gnome/gnucash-sheet.h	2010-10-30 14:55:23 UTC (rev 19733)
@@ -227,8 +227,6 @@
 void gnucash_register_attach_popup(GnucashRegister *reg, GtkWidget *popup,
                                    gpointer data);
 
-void gnucash_register_set_initial_rows(guint num_rows);
-
 gboolean gnucash_register_has_selection (GnucashRegister *reg);
 void gnucash_register_cut_clipboard (GnucashRegister *reg);
 void gnucash_register_copy_clipboard (GnucashRegister *reg);



More information about the gnucash-changes mailing list
--- gnucash/trunk/src/register/register-gnome/gnucash-sheet.c	2010-10-30 01:55:55 UTC (rev 19732)
+++ gnucash/trunk/src/register/register-gnome/gnucash-sheet.c	2010-10-30 14:55:23 UTC (rev 19733)
@@ -45,6 +45,8 @@
 
 #define DEFAULT_REGISTER_HEIGHT 400
 #define DEFAULT_REGISTER_WIDTH  400
+/* Used to calculate the minimum preferred height of the register window: */
+#define DEFAULT_REGISTER_INITIAL_ROWS 10
 
 
 /* Register signals */
@@ -61,7 +63,6 @@
 
 /* This static indicates the debugging module that this .o belongs to. */
 static QofLogModule log_module = GNC_MOD_REGISTER;
-static guint gnucash_register_initial_rows = 15;
 static GnomeCanvasClass *sheet_parent_class;
 static GtkTableClass *register_parent_class;
 static guint register_signals[LAST_SIGNAL];
@@ -94,12 +95,6 @@
 
 /** Implementation *****************************************************/
 
-void
-gnucash_register_set_initial_rows (guint num_rows)
-{
-    gnucash_register_initial_rows = num_rows;
-}
-
 G_INLINE_FUNC gboolean
 gnucash_sheet_virt_cell_out_of_bounds (GnucashSheet *sheet,
                                        VirtualCellLocation vcell_loc);
@@ -749,7 +744,7 @@
 }
 
 
 /* Compute the height needed to show DEFAULT_REGISTER_ROWS rows */
 static gint
 compute_optimal_height (GnucashSheet *sheet)
 {
@@ -770,7 +765,7 @@
 
     row_height = cd->pixel_height;
 
-    return row_height * gnucash_register_initial_rows;
+    return row_height * DEFAULT_REGISTER_INITIAL_ROWS;
 }
 
 
@@ -749,7 +744,7 @@
 
 
-/* Compute the height needed to show DEFAULT_REGISTER_ROWS rows */
+/* Compute the height needed to show DEFAULT_REGISTER_INITIAL_ROWS rows */
 static gint
 compute_optimal_height (GnucashSheet *sheet)

Modified: gnucash/trunk/src/register/register-gnome/gnucash-sheet.h
===================================================================